@@ -15,9 +15,9 @@ import statistics as st
 
 import math
 
-from extra import refmfe, SHIFT_CONST
+from premirnaplot.extra import refmfe, SHIFT_CONST
 
-from imgparser import SVGconstructor
+from premirnaplot.imgparser import SVGconstructor
 
 
 class Precursor():
